@@ -2,8 +2,6 @@ import traceback
 
 import pandas as pd
 import pytest
-from pytest_html import extras
-from .utils.general.Wrapit import Wrapit
 from .drivers.browsers import browser_os_name_conf
 from .conf.rwd.Website import base_url_conf
 from .utils import html_report_conf
@@ -215,20 +213,6 @@ def pytest_configure(config):
     config.addinivalue_line("markers", "MOBILE: mark a test as part of the GUI regression suite.")
 
 
-@pytest.hookimpl(hookwrapper=True)
-def pytest_runtest_makereport(item, call):
-    pytest_html = item.config.pluginmanager.getplugin("html")
-    outcome = yield
-    report = outcome.get_result()
-    extra = getattr(report, "extra", [])
-    if report.when == "call":
-        test_func = item.parent.obj
-        screenshot_name = '%003d' % Wrapit.screenshot_counter + '' + test_func.__name__
-        # extra.append(pytest_html.extras.url(test_obj.screenshot_dir, name="Screenshot Folder"))
-        filename = f'{screenshot_name}.png'
-        extra.append(pytest_html.extras.image(filename))
-        report.extra = extra
-
 @pytest.hookimpl(tryfirst=True)
 def pytest_configure(config):
     filename = 'report_' + datetime.now().strftime(
